summaryrefslogtreecommitdiffstats
path: root/remoting
diff options
context:
space:
mode:
authorsergeyu@chromium.org <sergeyu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-05 00:08:10 +0000
committersergeyu@chromium.org <sergeyu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-05 00:08:10 +0000
commit3268023f1382463baf9ac9537664b90ab4ae6883 (patch)
tree286c919264367f10ff289f0828ba2a713eaf523e /remoting
parent44da8217868a044e283062254c0bf02f0c66f0a1 (diff)
downloadchromium_src-3268023f1382463baf9ac9537664b90ab4ae6883.zip
chromium_src-3268023f1382463baf9ac9537664b90ab4ae6883.tar.gz
chromium_src-3268023f1382463baf9ac9537664b90ab4ae6883.tar.bz2
Rename ClientSocket to StreamSocket.
BUG=80895 TEST=Compiles Review URL: http://codereview.chromium.org/6930014 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@84167 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting')
-rw-r--r--remoting/jingle_glue/ssl_socket_adapter.h8
-rw-r--r--remoting/protocol/jingle_session.cc2
-rw-r--r--remoting/protocol/jingle_session.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/remoting/protocol/jingle_session.cc b/remoting/protocol/jingle_session.cc
index a53aeb4..0f50bab 100644
--- a/remoting/protocol/jingle_session.cc
+++ b/remoting/protocol/jingle_session.cc
@@ -41,7 +41,7 @@ const char kVideoRtcpChannelName[] = "videortcp";
// Helper method to create a SSL client socket.
net::SSLClientSocket* CreateSSLClientSocket(
- net::ClientSocket* socket, scoped_refptr<net::X509Certificate> cert,
+ net::StreamSocket* socket, scoped_refptr<net::X509Certificate> cert,
net::CertVerifier* cert_verifier) {
net::SSLConfig ssl_config;
ssl_config.false_start_enabled = false;
diff --git a/remoting/protocol/jingle_session.h b/remoting/protocol/jingle_session.h
index d919d56..122aec8 100644
--- a/remoting/protocol/jingle_session.h
+++ b/remoting/protocol/jingle_session.h
@@ -20,9 +20,9 @@ class TransportChannelSocketAdapter;
namespace net {
class CertVerifier;
-class ClientSocket;
class ClientSocketFactory;
class Socket;
+class StreamSocket;
class X509Certificate;
} // namespace net
diff --git a/remoting/jingle_glue/ssl_socket_adapter.h b/remoting/jingle_glue/ssl_socket_adapter.h
index c4111c8..279e9e1 100644
--- a/remoting/jingle_glue/ssl_socket_adapter.h
+++ b/remoting/jingle_glue/ssl_socket_adapter.h
@@ -10,8 +10,8 @@
#include "net/base/io_buffer.h"
#include "net/base/net_errors.h"
#include "net/base/net_log.h"
-#include "net/socket/client_socket.h"
#include "net/socket/ssl_client_socket.h"
+#include "net/socket/stream_socket.h"
#include "third_party/libjingle/source/talk/base/asyncsocket.h"
#include "third_party/libjingle/source/talk/base/ssladapter.h"
@@ -26,10 +26,10 @@ class SSLSocketAdapter;
// TODO(sergeyu): Write unittests for this code!
// This class provides a wrapper to libjingle's talk_base::AsyncSocket that
// implements Chromium's net::ClientSocket interface. It's used by
// SSLSocketAdapter to enable Chromium's SSL implementation to work over
// libjingle's socket class.
-class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> {
+class TransportSocket : public net::StreamSocket, public sigslot::has_slots<> {
public:
TransportSocket(talk_base::AsyncSocket* socket,
SSLSocketAdapter *ssl_adapter);
@@ -39,7 +39,7 @@ class TransportSocket : public net::ClientSocket, public sigslot::has_slots<> {
addr_ = addr;
}
- // net::ClientSocket implementation
+ // net::StreamSocket implementation
virtual int Connect(net::CompletionCallback* callback);
virtual void Disconnect();
@@ -26,10 +26,10 @@ class SSLSocketAdapter;
// TODO(sergeyu): Write unittests for this code!
// This class provides a wrapper to libjingle's talk_base::AsyncSocket that
-// implements Chromium's net::ClientSocket interface. It's used by
+// implements Chromium's net::StreamSocket interface. It's used by
// SSLSocketAdapter to enable Chromium's SSL implementation to work over
// libjingle's socket class.